parse_str_with_recovered

Function parse_str_with_recovered 

pub fn parse_str_with_recovered(
    input: &str,
    opts: &ParseOptions,
) -> (Result<Document, XmlError>, Vec<XmlError>)
Recovery-mode sibling of parse_str. Returns the (best-effort) parsed Document along with the list of non-fatal errors that recovery mode forgave. When ParseOptions::recovery_mode is false the second element is always empty and the first is the same Result as parse_str would have produced.